summaryrefslogtreecommitdiff
path: root/libavcodec/wmavoice.c
diff options
context:
space:
mode:
authorAnton Khirnov <anton@khirnov.net>2011-10-17 10:10:42 +0200
committerAnton Khirnov <anton@khirnov.net>2011-10-20 21:06:58 +0200
commit9f51c682ee83ecf0995648d4574ac09b52bbcb24 (patch)
treec5976926717940042b4b54cc56b35858914e3fa4 /libavcodec/wmavoice.c
parent6f89efeaa7eceb3408abb6e593d892ec819177a7 (diff)
lavc: use avpriv_ prefix for ff_copy_bits and align_put_bits.
They are used in lavf.
Diffstat (limited to 'libavcodec/wmavoice.c')
-rw-r--r--libavcodec/wmavoice.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/libavcodec/wmavoice.c b/libavcodec/wmavoice.c
index 3b805ac04b..2096d69870 100644
--- a/libavcodec/wmavoice.c
+++ b/libavcodec/wmavoice.c
@@ -1872,7 +1872,7 @@ static int parse_packet_header(WMAVoiceContext *s)
* @param size size of the source data, in bytes
* @param gb bit I/O context specifying the current position in the source.
* data. This function might use this to align the bit position to
* a whole-byte boundary before calling #ff_copy_bits() on aligned
* source data
* @param nbits the amount of bits to copy from source to target
*
@@ -1893,7 +1893,7 @@ static void copy_bits(PutBitContext *pb,
rmn_bits &= 7; rmn_bytes >>= 3;
if ((rmn_bits = FFMIN(rmn_bits, nbits)) > 0)
put_bits(pb, rmn_bits, get_bits(gb, rmn_bits));
- ff_copy_bits(pb, data + size - rmn_bytes,
+ avpriv_copy_bits(pb, data + size - rmn_bytes,
FFMIN(nbits - rmn_bits, rmn_bytes << 3));
}
@@ -1872,7 +1872,7 @@ static int parse_packet_header(WMAVoiceContext *s)
* @param gb bit I/O context specifying the current position in the source.
* data. This function might use this to align the bit position to
- * a whole-byte boundary before calling #ff_copy_bits() on aligned
+ * a whole-byte boundary before calling #avpriv_copy_bits() on aligned
* source data
* @param nbits the amount of bits to copy from source to target